#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExpenseCtrRuleInfo import ExpenseCtrRuleInfo


class AlipayEbppInvoiceExpenserulesSceneruleModifyModel(object):

    def __init__(self):
        self._account_id = None
        self._action = None
        self._agreement_no = None
        self._effective_end_date = None
        self._effective_start_date = None
        self._expense_ctrl_rule_info_list = None
        self._payment_policy = None
        self._standard_desc = None
        self._standard_id = None
        self._standard_name = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def effective_end_date(self):
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, value):
        self._effective_end_date = value
    @property
    def effective_start_date(self):
        return self._effective_start_date

    @effective_start_date.setter
    def effective_start_date(self, value):
        self._effective_start_date = value
    @property
    def expense_ctrl_rule_info_list(self):
        return self._expense_ctrl_rule_info_list

    @expense_ctrl_rule_info_list.setter
    def expense_ctrl_rule_info_list(self, value):
        if isinstance(value, list):
            self._expense_ctrl_rule_info_list = list()
            for i in value:
                if isinstance(i, ExpenseCtrRuleInfo):
                    self._expense_ctrl_rule_info_list.append(i)
                else:
                    self._expense_ctrl_rule_info_list.append(ExpenseCtrRuleInfo.from_alipay_dict(i))
    @property
    def payment_policy(self):
        return self._payment_policy

    @payment_policy.setter
    def payment_policy(self, value):
        self._payment_policy = value
    @property
    def standard_desc(self):
        return self._standard_desc

    @standard_desc.setter
    def standard_desc(self, value):
        self._standard_desc = value
    @property
    def standard_id(self):
        return self._standard_id

    @standard_id.setter
    def standard_id(self, value):
        self._standard_id = value
    @property
    def standard_name(self):
        return self._standard_name

    @standard_name.setter
    def standard_name(self, value):
        self._standard_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.effective_end_date:
            if hasattr(self.effective_end_date, 'to_alipay_dict'):
                params['effective_end_date'] = self.effective_end_date.to_alipay_dict()
            else:
                params['effective_end_date'] = self.effective_end_date
        if self.effective_start_date:
            if hasattr(self.effective_start_date, 'to_alipay_dict'):
                params['effective_start_date'] = self.effective_start_date.to_alipay_dict()
            else:
                params['effective_start_date'] = self.effective_start_date
        if self.expense_ctrl_rule_info_list:
            if isinstance(self.expense_ctrl_rule_info_list, list):
                for i in range(0, len(self.expense_ctrl_rule_info_list)):
                    element = self.expense_ctrl_rule_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.expense_ctrl_rule_info_list[i] = element.to_alipay_dict()
            if hasattr(self.expense_ctrl_rule_info_list, 'to_alipay_dict'):
                params['expense_ctrl_rule_info_list'] = self.expense_ctrl_rule_info_list.to_alipay_dict()
            else:
                params['expense_ctrl_rule_info_list'] = self.expense_ctrl_rule_info_list
        if self.payment_policy:
            if hasattr(self.payment_policy, 'to_alipay_dict'):
                params['payment_policy'] = self.payment_policy.to_alipay_dict()
            else:
                params['payment_policy'] = self.payment_policy
        if self.standard_desc:
            if hasattr(self.standard_desc, 'to_alipay_dict'):
                params['standard_desc'] = self.standard_desc.to_alipay_dict()
            else:
                params['standard_desc'] = self.standard_desc
        if self.standard_id:
            if hasattr(self.standard_id, 'to_alipay_dict'):
                params['standard_id'] = self.standard_id.to_alipay_dict()
            else:
                params['standard_id'] = self.standard_id
        if self.standard_name:
            if hasattr(self.standard_name, 'to_alipay_dict'):
                params['standard_name'] = self.standard_name.to_alipay_dict()
            else:
                params['standard_name'] = self.standard_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceExpenserulesSceneruleModifyModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'action' in d:
            o.action = d['action']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'effective_end_date' in d:
            o.effective_end_date = d['effective_end_date']
        if 'effective_start_date' in d:
            o.effective_start_date = d['effective_start_date']
        if 'expense_ctrl_rule_info_list' in d:
            o.expense_ctrl_rule_info_list = d['expense_ctrl_rule_info_list']
        if 'payment_policy' in d:
            o.payment_policy = d['payment_policy']
        if 'standard_desc' in d:
            o.standard_desc = d['standard_desc']
        if 'standard_id' in d:
            o.standard_id = d['standard_id']
        if 'standard_name' in d:
            o.standard_name = d['standard_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AdUserQualification(object):

    def __init__(self):
        self._approver = None
        self._audit_reason = None
        self._audit_status = None
        self._audit_time = None
        self._file_url = None
        self._id = None
        self._qualification_name = None

    @property
    def approver(self):
        return self._approver

    @approver.setter
    def approver(self, value):
        self._approver = value
    @property
    def audit_reason(self):
        return self._audit_reason

    @audit_reason.setter
    def audit_reason(self, value):
        self._audit_reason = value
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def audit_time(self):
        return self._audit_time

    @audit_time.setter
    def audit_time(self, value):
        self._audit_time = value
    @property
    def file_url(self):
        return self._file_url

    @file_url.setter
    def file_url(self, value):
        if isinstance(value, list):
            self._file_url = list()
            for i in value:
                self._file_url.append(i)
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def qualification_name(self):
        return self._qualification_name

    @qualification_name.setter
    def qualification_name(self, value):
        self._qualification_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.approver:
            if hasattr(self.approver, 'to_alipay_dict'):
                params['approver'] = self.approver.to_alipay_dict()
            else:
                params['approver'] = self.approver
        if self.audit_reason:
            if hasattr(self.audit_reason, 'to_alipay_dict'):
                params['audit_reason'] = self.audit_reason.to_alipay_dict()
            else:
                params['audit_reason'] = self.audit_reason
        if self.audit_status:
            if hasattr(self.audit_status, 'to_alipay_dict'):
                params['audit_status'] = self.audit_status.to_alipay_dict()
            else:
                params['audit_status'] = self.audit_status
        if self.audit_time:
            if hasattr(self.audit_time, 'to_alipay_dict'):
                params['audit_time'] = self.audit_time.to_alipay_dict()
            else:
                params['audit_time'] = self.audit_time
        if self.file_url:
            if isinstance(self.file_url, list):
                for i in range(0, len(self.file_url)):
                    element = self.file_url[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.file_url[i] = element.to_alipay_dict()
            if hasattr(self.file_url, 'to_alipay_dict'):
                params['file_url'] = self.file_url.to_alipay_dict()
            else:
                params['file_url'] = self.file_url
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.qualification_name:
            if hasattr(self.qualification_name, 'to_alipay_dict'):
                params['qualification_name'] = self.qualification_name.to_alipay_dict()
            else:
                params['qualification_name'] = self.qualification_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AdUserQualification()
        if 'approver' in d:
            o.approver = d['approver']
        if 'audit_reason' in d:
            o.audit_reason = d['audit_reason']
        if 'audit_status' in d:
            o.audit_status = d['audit_status']
        if 'audit_time' in d:
            o.audit_time = d['audit_time']
        if 'file_url' in d:
            o.file_url = d['file_url']
        if 'id' in d:
            o.id = d['id']
        if 'qualification_name' in d:
            o.qualification_name = d['qualification_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ItemResp import ItemResp


class KoubeiMarketingDataMallRecommendGetResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingDataMallRecommendGetResponse, self).__init__()
        self._has_more = None
        self._items = None

    @property
    def has_more(self):
        return self._has_more

    @has_more.setter
    def has_more(self, value):
        self._has_more = value
    @property
    def items(self):
        return self._items

    @items.setter
    def items(self, value):
        if isinstance(value, list):
            self._items = list()
            for i in value:
                if isinstance(i, ItemResp):
                    self._items.append(i)
                else:
                    self._items.append(ItemResp.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingDataMallRecommendGetResponse, self).parse_response_content(response_content)
        if 'has_more' in response:
            self.has_more = response['has_more']
        if 'items' in response:
            self.items = response['items']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignUserVoucherBatchqueryModel(object):

    def __init__(self):
        self._page_number = None
        self._page_size = None
        self._voucher_status = None

    @property
    def page_number(self):
        return self._page_number

    @page_number.setter
    def page_number(self, value):
        self._page_number = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def voucher_status(self):
        return self._voucher_status

    @voucher_status.setter
    def voucher_status(self, value):
        self._voucher_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.page_number:
            if hasattr(self.page_number, 'to_alipay_dict'):
                params['page_number'] = self.page_number.to_alipay_dict()
            else:
                params['page_number'] = self.page_number
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.voucher_status:
            if hasattr(self.voucher_status, 'to_alipay_dict'):
                params['voucher_status'] = self.voucher_status.to_alipay_dict()
            else:
                params['voucher_status'] = self.voucher_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignUserVoucherBatchqueryModel()
        if 'page_number' in d:
            o.page_number = d['page_number']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'voucher_status' in d:
            o.voucher_status = d['voucher_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MyBkAccountVO import MyBkAccountVO


class MybankCreditLoantradeRepayCustApplyModel(object):

    def __init__(self):
        self._apply_repay_fee = None
        self._apply_repay_int = None
        self._apply_repay_pre_fee = None
        self._apply_repay_prin = None
        self._discount_amt = None
        self._ext_data = None
        self._ip_id = None
        self._ip_role_id = None
        self._loan_ar_no = None
        self._prom_tools = None
        self._repay_account = None
        self._repay_type = None
        self._request_id = None

    @property
    def apply_repay_fee(self):
        return self._apply_repay_fee

    @apply_repay_fee.setter
    def apply_repay_fee(self, value):
        self._apply_repay_fee = value
    @property
    def apply_repay_int(self):
        return self._apply_repay_int

    @apply_repay_int.setter
    def apply_repay_int(self, value):
        self._apply_repay_int = value
    @property
    def apply_repay_pre_fee(self):
        return self._apply_repay_pre_fee

    @apply_repay_pre_fee.setter
    def apply_repay_pre_fee(self, value):
        self._apply_repay_pre_fee = value
    @property
    def apply_repay_prin(self):
        return self._apply_repay_prin

    @apply_repay_prin.setter
    def apply_repay_prin(self, value):
        self._apply_repay_prin = value
    @property
    def discount_amt(self):
        return self._discount_amt

    @discount_amt.setter
    def discount_amt(self, value):
        self._discount_amt = value
    @property
    def ext_data(self):
        return self._ext_data

    @ext_data.setter
    def ext_data(self, value):
        self._ext_data = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def loan_ar_no(self):
        return self._loan_ar_no

    @loan_ar_no.setter
    def loan_ar_no(self, value):
        self._loan_ar_no = value
    @property
    def prom_tools(self):
        return self._prom_tools

    @prom_tools.setter
    def prom_tools(self, value):
        if isinstance(value, list):
            self._prom_tools = list()
            for i in value:
                self._prom_tools.append(i)
    @property
    def repay_account(self):
        return self._repay_account

    @repay_account.setter
    def repay_account(self, value):
        if isinstance(value, MyBkAccountVO):
            self._repay_account = value
        else:
            self._repay_account = MyBkAccountVO.from_alipay_dict(value)
    @property
    def repay_type(self):
        return self._repay_type

    @repay_type.setter
    def repay_type(self, value):
        self._repay_type = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_repay_fee:
            if hasattr(self.apply_repay_fee, 'to_alipay_dict'):
                params['apply_repay_fee'] = self.apply_repay_fee.to_alipay_dict()
            else:
                params['apply_repay_fee'] = self.apply_repay_fee
        if self.apply_repay_int:
            if hasattr(self.apply_repay_int, 'to_alipay_dict'):
                params['apply_repay_int'] = self.apply_repay_int.to_alipay_dict()
            else:
                params['apply_repay_int'] = self.apply_repay_int
        if self.apply_repay_pre_fee:
            if hasattr(self.apply_repay_pre_fee, 'to_alipay_dict'):
                params['apply_repay_pre_fee'] = self.apply_repay_pre_fee.to_alipay_dict()
            else:
                params['apply_repay_pre_fee'] = self.apply_repay_pre_fee
        if self.apply_repay_prin:
            if hasattr(self.apply_repay_prin, 'to_alipay_dict'):
                params['apply_repay_prin'] = self.apply_repay_prin.to_alipay_dict()
            else:
                params['apply_repay_prin'] = self.apply_repay_prin
        if self.discount_amt:
            if hasattr(self.discount_amt, 'to_alipay_dict'):
                params['discount_amt'] = self.discount_amt.to_alipay_dict()
            else:
                params['discount_amt'] = self.discount_amt
        if self.ext_data:
            if hasattr(self.ext_data, 'to_alipay_dict'):
                params['ext_data'] = self.ext_data.to_alipay_dict()
            else:
                params['ext_data'] = self.ext_data
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.loan_ar_no:
            if hasattr(self.loan_ar_no, 'to_alipay_dict'):
                params['loan_ar_no'] = self.loan_ar_no.to_alipay_dict()
            else:
                params['loan_ar_no'] = self.loan_ar_no
        if self.prom_tools:
            if isinstance(self.prom_tools, list):
                for i in range(0, len(self.prom_tools)):
                    element = self.prom_tools[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.prom_tools[i] = element.to_alipay_dict()
            if hasattr(self.prom_tools, 'to_alipay_dict'):
                params['prom_tools'] = self.prom_tools.to_alipay_dict()
            else:
                params['prom_tools'] = self.prom_tools
        if self.repay_account:
            if hasattr(self.repay_account, 'to_alipay_dict'):
                params['repay_account'] = self.repay_account.to_alipay_dict()
            else:
                params['repay_account'] = self.repay_account
        if self.repay_type:
            if hasattr(self.repay_type, 'to_alipay_dict'):
                params['repay_type'] = self.repay_type.to_alipay_dict()
            else:
                params['repay_type'] = self.repay_type
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeRepayCustApplyModel()
        if 'apply_repay_fee' in d:
            o.apply_repay_fee = d['apply_repay_fee']
        if 'apply_repay_int' in d:
            o.apply_repay_int = d['apply_repay_int']
        if 'apply_repay_pre_fee' in d:
            o.apply_repay_pre_fee = d['apply_repay_pre_fee']
        if 'apply_repay_prin' in d:
            o.apply_repay_prin = d['apply_repay_prin']
        if 'discount_amt' in d:
            o.discount_amt = d['discount_amt']
        if 'ext_data' in d:
            o.ext_data = d['ext_data']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'loan_ar_no' in d:
            o.loan_ar_no = d['loan_ar_no']
        if 'prom_tools' in d:
            o.prom_tools = d['prom_tools']
        if 'repay_account' in d:
            o.repay_account = d['repay_account']
        if 'repay_type' in d:
            o.repay_type = d['repay_type']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateTradeSyncModel(object):

    def __init__(self):
        self._edu_trade_no = None
        self._out_order_no = None
        self._pay_amount = None
        self._pay_time = None
        self._trade_no = None
        self._trade_status = None

    @property
    def edu_trade_no(self):
        return self._edu_trade_no

    @edu_trade_no.setter
    def edu_trade_no(self, value):
        self._edu_trade_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_status(self):
        return self._trade_status

    @trade_status.setter
    def trade_status(self, value):
        self._trade_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.edu_trade_no:
            if hasattr(self.edu_trade_no, 'to_alipay_dict'):
                params['edu_trade_no'] = self.edu_trade_no.to_alipay_dict()
            else:
                params['edu_trade_no'] = self.edu_trade_no
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_status:
            if hasattr(self.trade_status, 'to_alipay_dict'):
                params['trade_status'] = self.trade_status.to_alipay_dict()
            else:
                params['trade_status'] = self.trade_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateTradeSyncModel()
        if 'edu_trade_no' in d:
            o.edu_trade_no = d['edu_trade_no']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_status' in d:
            o.trade_status = d['trade_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TaskVoucherInfo(object):

    def __init__(self):
        self._shop_voucher_sales_amount = None
        self._voucher_denomination = None
        self._voucher_icon_url = None
        self._voucher_name = None
        self._voucher_sales_amount = None
        self._voucher_template_id = None
        self._voucher_usage_threshold = None

    @property
    def shop_voucher_sales_amount(self):
        return self._shop_voucher_sales_amount

    @shop_voucher_sales_amount.setter
    def shop_voucher_sales_amount(self, value):
        self._shop_voucher_sales_amount = value
    @property
    def voucher_denomination(self):
        return self._voucher_denomination

    @voucher_denomination.setter
    def voucher_denomination(self, value):
        self._voucher_denomination = value
    @property
    def voucher_icon_url(self):
        return self._voucher_icon_url

    @voucher_icon_url.setter
    def voucher_icon_url(self, value):
        self._voucher_icon_url = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_sales_amount(self):
        return self._voucher_sales_amount

    @voucher_sales_amount.setter
    def voucher_sales_amount(self, value):
        self._voucher_sales_amount = value
    @property
    def voucher_template_id(self):
        return self._voucher_template_id

    @voucher_template_id.setter
    def voucher_template_id(self, value):
        self._voucher_template_id = value
    @property
    def voucher_usage_threshold(self):
        return self._voucher_usage_threshold

    @voucher_usage_threshold.setter
    def voucher_usage_threshold(self, value):
        self._voucher_usage_threshold = value


    def to_alipay_dict(self):
        params = dict()
        if self.shop_voucher_sales_amount:
            if hasattr(self.shop_voucher_sales_amount, 'to_alipay_dict'):
                params['shop_voucher_sales_amount'] = self.shop_voucher_sales_amount.to_alipay_dict()
            else:
                params['shop_voucher_sales_amount'] = self.shop_voucher_sales_amount
        if self.voucher_denomination:
            if hasattr(self.voucher_denomination, 'to_alipay_dict'):
                params['voucher_denomination'] = self.voucher_denomination.to_alipay_dict()
            else:
                params['voucher_denomination'] = self.voucher_denomination
        if self.voucher_icon_url:
            if hasattr(self.voucher_icon_url, 'to_alipay_dict'):
                params['voucher_icon_url'] = self.voucher_icon_url.to_alipay_dict()
            else:
                params['voucher_icon_url'] = self.voucher_icon_url
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_sales_amount:
            if hasattr(self.voucher_sales_amount, 'to_alipay_dict'):
                params['voucher_sales_amount'] = self.voucher_sales_amount.to_alipay_dict()
            else:
                params['voucher_sales_amount'] = self.voucher_sales_amount
        if self.voucher_template_id:
            if hasattr(self.voucher_template_id, 'to_alipay_dict'):
                params['voucher_template_id'] = self.voucher_template_id.to_alipay_dict()
            else:
                params['voucher_template_id'] = self.voucher_template_id
        if self.voucher_usage_threshold:
            if hasattr(self.voucher_usage_threshold, 'to_alipay_dict'):
                params['voucher_usage_threshold'] = self.voucher_usage_threshold.to_alipay_dict()
            else:
                params['voucher_usage_threshold'] = self.voucher_usage_threshold
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TaskVoucherInfo()
        if 'shop_voucher_sales_amount' in d:
            o.shop_voucher_sales_amount = d['shop_voucher_sales_amount']
        if 'voucher_denomination' in d:
            o.voucher_denomination = d['voucher_denomination']
        if 'voucher_icon_url' in d:
            o.voucher_icon_url = d['voucher_icon_url']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_sales_amount' in d:
            o.voucher_sales_amount = d['voucher_sales_amount']
        if 'voucher_template_id' in d:
            o.voucher_template_id = d['voucher_template_id']
        if 'voucher_usage_threshold' in d:
            o.voucher_usage_threshold = d['voucher_usage_threshold']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayQueryCardModelResult(object):

    def __init__(self):
        self._balance = None
        self._card_data = None
        self._card_no = None
        self._card_status = None
        self._card_type = None
        self._ext_info = None
        self._last_update_time = None
        self._status_code = None
        self._status_msg = None
        self._user_auth_info = None
        self._user_id = None

    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def card_data(self):
        return self._card_data

    @card_data.setter
    def card_data(self, value):
        self._card_data = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def card_status(self):
        return self._card_status

    @card_status.setter
    def card_status(self, value):
        self._card_status = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def last_update_time(self):
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, value):
        self._last_update_time = value
    @property
    def status_code(self):
        return self._status_code

    @status_code.setter
    def status_code(self, value):
        self._status_code = value
    @property
    def status_msg(self):
        return self._status_msg

    @status_msg.setter
    def status_msg(self, value):
        self._status_msg = value
    @property
    def user_auth_info(self):
        return self._user_auth_info

    @user_auth_info.setter
    def user_auth_info(self, value):
        self._user_auth_info = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.card_data:
            if hasattr(self.card_data, 'to_alipay_dict'):
                params['card_data'] = self.card_data.to_alipay_dict()
            else:
                params['card_data'] = self.card_data
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.card_status:
            if hasattr(self.card_status, 'to_alipay_dict'):
                params['card_status'] = self.card_status.to_alipay_dict()
            else:
                params['card_status'] = self.card_status
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.last_update_time:
            if hasattr(self.last_update_time, 'to_alipay_dict'):
                params['last_update_time'] = self.last_update_time.to_alipay_dict()
            else:
                params['last_update_time'] = self.last_update_time
        if self.status_code:
            if hasattr(self.status_code, 'to_alipay_dict'):
                params['status_code'] = self.status_code.to_alipay_dict()
            else:
                params['status_code'] = self.status_code
        if self.status_msg:
            if hasattr(self.status_msg, 'to_alipay_dict'):
                params['status_msg'] = self.status_msg.to_alipay_dict()
            else:
                params['status_msg'] = self.status_msg
        if self.user_auth_info:
            if hasattr(self.user_auth_info, 'to_alipay_dict'):
                params['user_auth_info'] = self.user_auth_info.to_alipay_dict()
            else:
                params['user_auth_info'] = self.user_auth_info
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayQueryCardModelResult()
        if 'balance' in d:
            o.balance = d['balance']
        if 'card_data' in d:
            o.card_data = d['card_data']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'card_status' in d:
            o.card_status = d['card_status']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'last_update_time' in d:
            o.last_update_time = d['last_update_time']
        if 'status_code' in d:
            o.status_code = d['status_code']
        if 'status_msg' in d:
            o.status_msg = d['status_msg']
        if 'user_auth_info' in d:
            o.user_auth_info = d['user_auth_info']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialAntforestAccountTransferModel(object):

    def __init__(self):
        self._energy_account_from = None
        self._energy_account_to = None
        self._energy_count = None
        self._ext_info = None
        self._out_biz_no = None
        self._transfer_type = None
        self._user_id = None

    @property
    def energy_account_from(self):
        return self._energy_account_from

    @energy_account_from.setter
    def energy_account_from(self, value):
        self._energy_account_from = value
    @property
    def energy_account_to(self):
        return self._energy_account_to

    @energy_account_to.setter
    def energy_account_to(self, value):
        self._energy_account_to = value
    @property
    def energy_count(self):
        return self._energy_count

    @energy_count.setter
    def energy_count(self, value):
        self._energy_count = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def transfer_type(self):
        return self._transfer_type

    @transfer_type.setter
    def transfer_type(self, value):
        self._transfer_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.energy_account_from:
            if hasattr(self.energy_account_from, 'to_alipay_dict'):
                params['energy_account_from'] = self.energy_account_from.to_alipay_dict()
            else:
                params['energy_account_from'] = self.energy_account_from
        if self.energy_account_to:
            if hasattr(self.energy_account_to, 'to_alipay_dict'):
                params['energy_account_to'] = self.energy_account_to.to_alipay_dict()
            else:
                params['energy_account_to'] = self.energy_account_to
        if self.energy_count:
            if hasattr(self.energy_count, 'to_alipay_dict'):
                params['energy_count'] = self.energy_count.to_alipay_dict()
            else:
                params['energy_count'] = self.energy_count
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.transfer_type:
            if hasattr(self.transfer_type, 'to_alipay_dict'):
                params['transfer_type'] = self.transfer_type.to_alipay_dict()
            else:
                params['transfer_type'] = self.transfer_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialAntforestAccountTransferModel()
        if 'energy_account_from' in d:
            o.energy_account_from = d['energy_account_from']
        if 'energy_account_to' in d:
            o.energy_account_to = d['energy_account_to']
        if 'energy_count' in d:
            o.energy_count = d['energy_count']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'transfer_type' in d:
            o.transfer_type = d['transfer_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppInvoiceFileOutputQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceFileOutputQueryResponse, self).__init__()
        self._invoice_file_content = None

    @property
    def invoice_file_content(self):
        return self._invoice_file_content

    @invoice_file_content.setter
    def invoice_file_content(self, value):
        self._invoice_file_content = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceFileOutputQueryResponse, self).parse_response_content(response_content)
        if 'invoice_file_content' in response:
            self.invoice_file_content = response['invoice_file_content']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntlawSignOperator(object):

    def __init__(self):
        self._cert_type = None
        self._operator_cert_no = None
        self._operator_name = None
        self._operator_uid = None
        self._sign_operator_type = None

    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def operator_cert_no(self):
        return self._operator_cert_no

    @operator_cert_no.setter
    def operator_cert_no(self, value):
        self._operator_cert_no = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def operator_uid(self):
        return self._operator_uid

    @operator_uid.setter
    def operator_uid(self, value):
        self._operator_uid = value
    @property
    def sign_operator_type(self):
        return self._sign_operator_type

    @sign_operator_type.setter
    def sign_operator_type(self, value):
        self._sign_operator_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.operator_cert_no:
            if hasattr(self.operator_cert_no, 'to_alipay_dict'):
                params['operator_cert_no'] = self.operator_cert_no.to_alipay_dict()
            else:
                params['operator_cert_no'] = self.operator_cert_no
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.operator_uid:
            if hasattr(self.operator_uid, 'to_alipay_dict'):
                params['operator_uid'] = self.operator_uid.to_alipay_dict()
            else:
                params['operator_uid'] = self.operator_uid
        if self.sign_operator_type:
            if hasattr(self.sign_operator_type, 'to_alipay_dict'):
                params['sign_operator_type'] = self.sign_operator_type.to_alipay_dict()
            else:
                params['sign_operator_type'] = self.sign_operator_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntlawSignOperator()
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'operator_cert_no' in d:
            o.operator_cert_no = d['operator_cert_no']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'operator_uid' in d:
            o.operator_uid = d['operator_uid']
        if 'sign_operator_type' in d:
            o.sign_operator_type = d['sign_operator_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiMarketingCampaignTagsQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignTagsQueryResponse, self).__init__()
        self._tags = None

    @property
    def tags(self):
        return self._tags

    @tags.setter
    def tags(self, value):
        self._tags = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignTagsQueryResponse, self).parse_response_content(response_content)
        if 'tags' in response:
            self.tags = response['tags']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoBasicBizinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoBasicBizinfoQueryResponse, self).__init__()
        self._biz_inst = None
        self._biz_type = None
        self._data_code = None
        self._org_result_code = None
        self._org_result_msg = None
        self._result_code = None
        self._result_context = None
        self._result_msg = None

    @property
    def biz_inst(self):
        return self._biz_inst

    @biz_inst.setter
    def biz_inst(self, value):
        self._biz_inst = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def data_code(self):
        return self._data_code

    @data_code.setter
    def data_code(self, value):
        self._data_code = value
    @property
    def org_result_code(self):
        return self._org_result_code

    @org_result_code.setter
    def org_result_code(self, value):
        self._org_result_code = value
    @property
    def org_result_msg(self):
        return self._org_result_msg

    @org_result_msg.setter
    def org_result_msg(self, value):
        self._org_result_msg = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_context(self):
        return self._result_context

    @result_context.setter
    def result_context(self, value):
        self._result_context = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoBasicBizinfoQueryResponse, self).parse_response_content(response_content)
        if 'biz_inst' in response:
            self.biz_inst = response['biz_inst']
        if 'biz_type' in response:
            self.biz_type = response['biz_type']
        if 'data_code' in response:
            self.data_code = response['data_code']
        if 'org_result_code' in response:
            self.org_result_code = response['org_result_code']
        if 'org_result_msg' in response:
            self.org_result_msg = response['org_result_msg']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_context' in response:
            self.result_context = response['result_context']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossBaseProcessInstanceUrgeModel(object):

    def __init__(self):
        self._code = None
        self._msg_template = None
        self._msg_type_list = None
        self._puid = None
        self._title = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def msg_template(self):
        return self._msg_template

    @msg_template.setter
    def msg_template(self, value):
        self._msg_template = value
    @property
    def msg_type_list(self):
        return self._msg_type_list

    @msg_type_list.setter
    def msg_type_list(self, value):
        if isinstance(value, list):
            self._msg_type_list = list()
            for i in value:
                self._msg_type_list.append(i)
    @property
    def puid(self):
        return self._puid

    @puid.setter
    def puid(self, value):
        self._puid = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.msg_template:
            if hasattr(self.msg_template, 'to_alipay_dict'):
                params['msg_template'] = self.msg_template.to_alipay_dict()
            else:
                params['msg_template'] = self.msg_template
        if self.msg_type_list:
            if isinstance(self.msg_type_list, list):
                for i in range(0, len(self.msg_type_list)):
                    element = self.msg_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.msg_type_list[i] = element.to_alipay_dict()
            if hasattr(self.msg_type_list, 'to_alipay_dict'):
                params['msg_type_list'] = self.msg_type_list.to_alipay_dict()
            else:
                params['msg_type_list'] = self.msg_type_list
        if self.puid:
            if hasattr(self.puid, 'to_alipay_dict'):
                params['puid'] = self.puid.to_alipay_dict()
            else:
                params['puid'] = self.puid
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossBaseProcessInstanceUrgeModel()
        if 'code' in d:
            o.code = d['code']
        if 'msg_template' in d:
            o.msg_template = d['msg_template']
        if 'msg_type_list' in d:
            o.msg_type_list = d['msg_type_list']
        if 'puid' in d:
            o.puid = d['puid']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserWufufukaAliyunExchangeResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserWufufukaAliyunExchangeResponse, self).__init__()
        self._refund_flag = None

    @property
    def refund_flag(self):
        return self._refund_flag

    @refund_flag.setter
    def refund_flag(self, value):
        self._refund_flag = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserWufufukaAliyunExchangeResponse, self).parse_response_content(response_content)
        if 'refund_flag' in response:
            self.refund_flag = response['refund_flag']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RecruitShopInfo import RecruitShopInfo


class KoubeiMarketingCampaignRecruitShopQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingCampaignRecruitShopQueryResponse, self).__init__()
        self._plan_id = None
        self._shop_count = None
        self._shop_info = None

    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value
    @property
    def shop_count(self):
        return self._shop_count

    @shop_count.setter
    def shop_count(self, value):
        self._shop_count = value
    @property
    def shop_info(self):
        return self._shop_info

    @shop_info.setter
    def shop_info(self, value):
        if isinstance(value, list):
            self._shop_info = list()
            for i in value:
                if isinstance(i, RecruitShopInfo):
                    self._shop_info.append(i)
                else:
                    self._shop_info.append(RecruitShopInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingCampaignRecruitShopQueryResponse, self).parse_response_content(response_content)
        if 'plan_id' in response:
            self.plan_id = response['plan_id']
        if 'shop_count' in response:
            self.shop_count = response['shop_count']
        if 'shop_info' in response:
            self.shop_info = response['shop_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbdishMaterialInfo import KbdishMaterialInfo


class KoubeiCateringDishMaterialModifyResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringDishMaterialModifyResponse, self).__init__()
        self._kb_dish_material_info = None

    @property
    def kb_dish_material_info(self):
        return self._kb_dish_material_info

    @kb_dish_material_info.setter
    def kb_dish_material_info(self, value):
        if isinstance(value, KbdishMaterialInfo):
            self._kb_dish_material_info = value
        else:
            self._kb_dish_material_info = KbdishMaterialInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringDishMaterialModifyResponse, self).parse_response_content(response_content)
        if 'kb_dish_material_info' in response:
            self.kb_dish_material_info = response['kb_dish_material_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SimpleShopInfo import SimpleShopInfo


class AntMerchantExpandShopBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandShopBatchqueryResponse, self).__init__()
        self._page_no = None
        self._page_size = None
        self._shops = None
        self._total_page = None
        self._total_size = None

    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def shops(self):
        return self._shops

    @shops.setter
    def shops(self, value):
        if isinstance(value, list):
            self._shops = list()
            for i in value:
                if isinstance(i, SimpleShopInfo):
                    self._shops.append(i)
                else:
                    self._shops.append(SimpleShopInfo.from_alipay_dict(i))
    @property
    def total_page(self):
        return self._total_page

    @total_page.setter
    def total_page(self, value):
        self._total_page = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandShopBatchqueryResponse, self).parse_response_content(response_content)
        if 'page_no' in response:
            self.page_no = response['page_no']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'shops' in response:
            self.shops = response['shops']
        if 'total_page' in response:
            self.total_page = response['total_page']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppAppcontentItemBatchqueryModel(object):

    def __init__(self):
        self._item_ids = None

    @property
    def item_ids(self):
        return self._item_ids

    @item_ids.setter
    def item_ids(self, value):
        if isinstance(value, list):
            self._item_ids = list()
            for i in value:
                self._item_ids.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.item_ids:
            if isinstance(self.item_ids, list):
                for i in range(0, len(self.item_ids)):
                    element = self.item_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_ids[i] = element.to_alipay_dict()
            if hasattr(self.item_ids, 'to_alipay_dict'):
                params['item_ids'] = self.item_ids.to_alipay_dict()
            else:
                params['item_ids'] = self.item_ids
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppAppcontentItemBatchqueryModel()
        if 'item_ids' in d:
            o.item_ids = d['item_ids']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayBossFncInvoiceMailinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossFncInvoiceMailinfoQueryResponse, self).__init__()
        self._creator = None
        self._express_company_name = None
        self._gmt_create = None
        self._gmt_modified = None
        self._invoice_id = None
        self._last_modifier = None
        self._mail_date = None
        self._mail_id = None
        self._reason = None
        self._recipients_address = None
        self._recipients_name = None
        self._recipients_tel = None
        self._sender_address = None
        self._sender_name = None
        self._sender_tel = None
        self._tnt_inst_id = None
        self._tracking_no = None

    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def express_company_name(self):
        return self._express_company_name

    @express_company_name.setter
    def express_company_name(self, value):
        self._express_company_name = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def invoice_id(self):
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, value):
        self._invoice_id = value
    @property
    def last_modifier(self):
        return self._last_modifier

    @last_modifier.setter
    def last_modifier(self, value):
        self._last_modifier = value
    @property
    def mail_date(self):
        return self._mail_date

    @mail_date.setter
    def mail_date(self, value):
        self._mail_date = value
    @property
    def mail_id(self):
        return self._mail_id

    @mail_id.setter
    def mail_id(self, value):
        self._mail_id = value
    @property
    def reason(self):
        return self._reason

    @reason.setter
    def reason(self, value):
        self._reason = value
    @property
    def recipients_address(self):
        return self._recipients_address

    @recipients_address.setter
    def recipients_address(self, value):
        self._recipients_address = value
    @property
    def recipients_name(self):
        return self._recipients_name

    @recipients_name.setter
    def recipients_name(self, value):
        self._recipients_name = value
    @property
    def recipients_tel(self):
        return self._recipients_tel

    @recipients_tel.setter
    def recipients_tel(self, value):
        self._recipients_tel = value
    @property
    def sender_address(self):
        return self._sender_address

    @sender_address.setter
    def sender_address(self, value):
        self._sender_address = value
    @property
    def sender_name(self):
        return self._sender_name

    @sender_name.setter
    def sender_name(self, value):
        self._sender_name = value
    @property
    def sender_tel(self):
        return self._sender_tel

    @sender_tel.setter
    def sender_tel(self, value):
        self._sender_tel = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def tracking_no(self):
        return self._tracking_no

    @tracking_no.setter
    def tracking_no(self, value):
        self._tracking_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayBossFncInvoiceMailinfoQueryResponse, self).parse_response_content(response_content)
        if 'creator' in response:
            self.creator = response['creator']
        if 'express_company_name' in response:
            self.express_company_name = response['express_company_name']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'gmt_modified' in response:
            self.gmt_modified = response['gmt_modified']
        if 'invoice_id' in response:
            self.invoice_id = response['invoice_id']
        if 'last_modifier' in response:
            self.last_modifier = response['last_modifier']
        if 'mail_date' in response:
            self.mail_date = response['mail_date']
        if 'mail_id' in response:
            self.mail_id = response['mail_id']
        if 'reason' in response:
            self.reason = response['reason']
        if 'recipients_address' in response:
            self.recipients_address = response['recipients_address']
        if 'recipients_name' in response:
            self.recipients_name = response['recipients_name']
        if 'recipients_tel' in response:
            self.recipients_tel = response['recipients_tel']
        if 'sender_address' in response:
            self.sender_address = response['sender_address']
        if 'sender_name' in response:
            self.sender_name = response['sender_name']
        if 'sender_tel' in response:
            self.sender_tel = response['sender_tel']
        if 'tnt_inst_id' in response:
            self.tnt_inst_id = response['tnt_inst_id']
        if 'tracking_no' in response:
            self.tracking_no = response['tracking_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialBaseChatGmsgSendModel(object):

    def __init__(self):
        self._biz_memo = None
        self._biz_type = None
        self._client_msg_id = None
        self._delivery_mode = None
        self._hidden_side = None
        self._link = None
        self._push_str = None
        self._range_users = None
        self._receiver_id = None
        self._receiver_usertype = None
        self._template_code = None
        self._template_data = None

    @property
    def biz_memo(self):
        return self._biz_memo

    @biz_memo.setter
    def biz_memo(self, value):
        self._biz_memo = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def client_msg_id(self):
        return self._client_msg_id

    @client_msg_id.setter
    def client_msg_id(self, value):
        self._client_msg_id = value
    @property
    def delivery_mode(self):
        return self._delivery_mode

    @delivery_mode.setter
    def delivery_mode(self, value):
        self._delivery_mode = value
    @property
    def hidden_side(self):
        return self._hidden_side

    @hidden_side.setter
    def hidden_side(self, value):
        self._hidden_side = value
    @property
    def link(self):
        return self._link

    @link.setter
    def link(self, value):
        self._link = value
    @property
    def push_str(self):
        return self._push_str

    @push_str.setter
    def push_str(self, value):
        self._push_str = value
    @property
    def range_users(self):
        return self._range_users

    @range_users.setter
    def range_users(self, value):
        if isinstance(value, list):
            self._range_users = list()
            for i in value:
                self._range_users.append(i)
    @property
    def receiver_id(self):
        return self._receiver_id

    @receiver_id.setter
    def receiver_id(self, value):
        self._receiver_id = value
    @property
    def receiver_usertype(self):
        return self._receiver_usertype

    @receiver_usertype.setter
    def receiver_usertype(self, value):
        self._receiver_usertype = value
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value
    @property
    def template_data(self):
        return self._template_data

    @template_data.setter
    def template_data(self, value):
        self._template_data = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_memo:
            if hasattr(self.biz_memo, 'to_alipay_dict'):
                params['biz_memo'] = self.biz_memo.to_alipay_dict()
            else:
                params['biz_memo'] = self.biz_memo
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.client_msg_id:
            if hasattr(self.client_msg_id, 'to_alipay_dict'):
                params['client_msg_id'] = self.client_msg_id.to_alipay_dict()
            else:
                params['client_msg_id'] = self.client_msg_id
        if self.delivery_mode:
            if hasattr(self.delivery_mode, 'to_alipay_dict'):
                params['delivery_mode'] = self.delivery_mode.to_alipay_dict()
            else:
                params['delivery_mode'] = self.delivery_mode
        if self.hidden_side:
            if hasattr(self.hidden_side, 'to_alipay_dict'):
                params['hidden_side'] = self.hidden_side.to_alipay_dict()
            else:
                params['hidden_side'] = self.hidden_side
        if self.link:
            if hasattr(self.link, 'to_alipay_dict'):
                params['link'] = self.link.to_alipay_dict()
            else:
                params['link'] = self.link
        if self.push_str:
            if hasattr(self.push_str, 'to_alipay_dict'):
                params['push_str'] = self.push_str.to_alipay_dict()
            else:
                params['push_str'] = self.push_str
        if self.range_users:
            if isinstance(self.range_users, list):
                for i in range(0, len(self.range_users)):
                    element = self.range_users[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.range_users[i] = element.to_alipay_dict()
            if hasattr(self.range_users, 'to_alipay_dict'):
                params['range_users'] = self.range_users.to_alipay_dict()
            else:
                params['range_users'] = self.range_users
        if self.receiver_id:
            if hasattr(self.receiver_id, 'to_alipay_dict'):
                params['receiver_id'] = self.receiver_id.to_alipay_dict()
            else:
                params['receiver_id'] = self.receiver_id
        if self.receiver_usertype:
            if hasattr(self.receiver_usertype, 'to_alipay_dict'):
                params['receiver_usertype'] = self.receiver_usertype.to_alipay_dict()
            else:
                params['receiver_usertype'] = self.receiver_usertype
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        if self.template_data:
            if hasattr(self.template_data, 'to_alipay_dict'):
                params['template_data'] = self.template_data.to_alipay_dict()
            else:
                params['template_data'] = self.template_data
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialBaseChatGmsgSendModel()
        if 'biz_memo' in d:
            o.biz_memo = d['biz_memo']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'client_msg_id' in d:
            o.client_msg_id = d['client_msg_id']
        if 'delivery_mode' in d:
            o.delivery_mode = d['delivery_mode']
        if 'hidden_side' in d:
            o.hidden_side = d['hidden_side']
        if 'link' in d:
            o.link = d['link']
        if 'push_str' in d:
            o.push_str = d['push_str']
        if 'range_users' in d:
            o.range_users = d['range_users']
        if 'receiver_id' in d:
            o.receiver_id = d['receiver_id']
        if 'receiver_usertype' in d:
            o.receiver_usertype = d['receiver_usertype']
        if 'template_code' in d:
            o.template_code = d['template_code']
        if 'template_data' in d:
            o.template_data = d['template_data']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PreOrderExtInfo(object):

    def __init__(self):
        self._brand_id = None
        self._brand_name = None
        self._channel = None
        self._order_feature = None

    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def order_feature(self):
        return self._order_feature

    @order_feature.setter
    def order_feature(self, value):
        self._order_feature = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.order_feature:
            if hasattr(self.order_feature, 'to_alipay_dict'):
                params['order_feature'] = self.order_feature.to_alipay_dict()
            else:
                params['order_feature'] = self.order_feature
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PreOrderExtInfo()
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'channel' in d:
            o.channel = d['channel']
        if 'order_feature' in d:
            o.order_feature = d['order_feature']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PaymentFixVoucher import PaymentFixVoucher
from alipay.aop.api.domain.PaymentVoucherValidPeriod import PaymentVoucherValidPeriod


class PaymentVoucherUseRuleDetail(object):

    def __init__(self):
        self._fix_voucher = None
        self._use_mode = None
        self._use_url = None
        self._voucher_quantity_limit_per_user = None
        self._voucher_quantity_limit_per_user_period_type = None
        self._voucher_valid_period = None

    @property
    def fix_voucher(self):
        return self._fix_voucher

    @fix_voucher.setter
    def fix_voucher(self, value):
        if isinstance(value, PaymentFixVoucher):
            self._fix_voucher = value
        else:
            self._fix_voucher = PaymentFixVoucher.from_alipay_dict(value)
    @property
    def use_mode(self):
        return self._use_mode

    @use_mode.setter
    def use_mode(self, value):
        self._use_mode = value
    @property
    def use_url(self):
        return self._use_url

    @use_url.setter
    def use_url(self, value):
        self._use_url = value
    @property
    def voucher_quantity_limit_per_user(self):
        return self._voucher_quantity_limit_per_user

    @voucher_quantity_limit_per_user.setter
    def voucher_quantity_limit_per_user(self, value):
        self._voucher_quantity_limit_per_user = value
    @property
    def voucher_quantity_limit_per_user_period_type(self):
        return self._voucher_quantity_limit_per_user_period_type

    @voucher_quantity_limit_per_user_period_type.setter
    def voucher_quantity_limit_per_user_period_type(self, value):
        self._voucher_quantity_limit_per_user_period_type = value
    @property
    def voucher_valid_period(self):
        return self._voucher_valid_period

    @voucher_valid_period.setter
    def voucher_valid_period(self, value):
        if isinstance(value, PaymentVoucherValidPeriod):
            self._voucher_valid_period = value
        else:
            self._voucher_valid_period = PaymentVoucherValidPeriod.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.fix_voucher:
            if hasattr(self.fix_voucher, 'to_alipay_dict'):
                params['fix_voucher'] = self.fix_voucher.to_alipay_dict()
            else:
                params['fix_voucher'] = self.fix_voucher
        if self.use_mode:
            if hasattr(self.use_mode, 'to_alipay_dict'):
                params['use_mode'] = self.use_mode.to_alipay_dict()
            else:
                params['use_mode'] = self.use_mode
        if self.use_url:
            if hasattr(self.use_url, 'to_alipay_dict'):
                params['use_url'] = self.use_url.to_alipay_dict()
            else:
                params['use_url'] = self.use_url
        if self.voucher_quantity_limit_per_user:
            if hasattr(self.voucher_quantity_limit_per_user, 'to_alipay_dict'):
                params['voucher_quantity_limit_per_user'] = self.voucher_quantity_limit_per_user.to_alipay_dict()
            else:
                params['voucher_quantity_limit_per_user'] = self.voucher_quantity_limit_per_user
        if self.voucher_quantity_limit_per_user_period_type:
            if hasattr(self.voucher_quantity_limit_per_user_period_type, 'to_alipay_dict'):
                params['voucher_quantity_limit_per_user_period_type'] = self.voucher_quantity_limit_per_user_period_type.to_alipay_dict()
            else:
                params['voucher_quantity_limit_per_user_period_type'] = self.voucher_quantity_limit_per_user_period_type
        if self.voucher_valid_period:
            if hasattr(self.voucher_valid_period, 'to_alipay_dict'):
                params['voucher_valid_period'] = self.voucher_valid_period.to_alipay_dict()
            else:
                params['voucher_valid_period'] = self.voucher_valid_period
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentVoucherUseRuleDetail()
        if 'fix_voucher' in d:
            o.fix_voucher = d['fix_voucher']
        if 'use_mode' in d:
            o.use_mode = d['use_mode']
        if 'use_url' in d:
            o.use_url = d['use_url']
        if 'voucher_quantity_limit_per_user' in d:
            o.voucher_quantity_limit_per_user = d['voucher_quantity_limit_per_user']
        if 'voucher_quantity_limit_per_user_period_type' in d:
            o.voucher_quantity_limit_per_user_period_type = d['voucher_quantity_limit_per_user_period_type']
        if 'voucher_valid_period' in d:
            o.voucher_valid_period = d['voucher_valid_period']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarOrderRefundModel(object):

    def __init__(self):
        self._order_no = None
        self._refund_fee = None
        self._refund_reason = None
        self._req_no = None

    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def refund_fee(self):
        return self._refund_fee

    @refund_fee.setter
    def refund_fee(self, value):
        self._refund_fee = value
    @property
    def refund_reason(self):
        return self._refund_reason

    @refund_reason.setter
    def refund_reason(self, value):
        self._refund_reason = value
    @property
    def req_no(self):
        return self._req_no

    @req_no.setter
    def req_no(self, value):
        self._req_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.refund_fee:
            if hasattr(self.refund_fee, 'to_alipay_dict'):
                params['refund_fee'] = self.refund_fee.to_alipay_dict()
            else:
                params['refund_fee'] = self.refund_fee
        if self.refund_reason:
            if hasattr(self.refund_reason, 'to_alipay_dict'):
                params['refund_reason'] = self.refund_reason.to_alipay_dict()
            else:
                params['refund_reason'] = self.refund_reason
        if self.req_no:
            if hasattr(self.req_no, 'to_alipay_dict'):
                params['req_no'] = self.req_no.to_alipay_dict()
            else:
                params['req_no'] = self.req_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarOrderRefundModel()
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'refund_fee' in d:
            o.refund_fee = d['refund_fee']
        if 'refund_reason' in d:
            o.refund_reason = d['refund_reason']
        if 'req_no' in d:
            o.req_no = d['req_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.GFAOpenAPIQueryRequest import GFAOpenAPIQueryRequest


class AlipayBossFncGfacceptanceDetailQueryModel(object):

    def __init__(self):
        self._principal_id = None
        self._query = None

    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def query(self):
        return self._query

    @query.setter
    def query(self, value):
        if isinstance(value, GFAOpenAPIQueryRequest):
            self._query = value
        else:
            self._query = GFAOpenAPIQueryRequest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.query:
            if hasattr(self.query, 'to_alipay_dict'):
                params['query'] = self.query.to_alipay_dict()
            else:
                params['query'] = self.query
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfacceptanceDetailQueryModel()
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'query' in d:
            o.query = d['query']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TimeCardConsumeCardInfo import TimeCardConsumeCardInfo
from alipay.aop.api.domain.TimeCardConsumerRecordInfo import TimeCardConsumerRecordInfo


class AlipayCommerceOperationTimescardConsumelistQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationTimescardConsumelistQueryResponse, self).__init__()
        self._card_info = None
        self._consume_record = None

    @property
    def card_info(self):
        return self._card_info

    @card_info.setter
    def card_info(self, value):
        if isinstance(value, TimeCardConsumeCardInfo):
            self._card_info = value
        else:
            self._card_info = TimeCardConsumeCardInfo.from_alipay_dict(value)
    @property
    def consume_record(self):
        return self._consume_record

    @consume_record.setter
    def consume_record(self, value):
        if isinstance(value, list):
            self._consume_record = list()
            for i in value:
                if isinstance(i, TimeCardConsumerRecordInfo):
                    self._consume_record.append(i)
                else:
                    self._consume_record.append(TimeCardConsumerRecordInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationTimescardConsumelistQueryResponse, self).parse_response_content(response_content)
        if 'card_info' in response:
            self.card_info = response['card_info']
        if 'consume_record' in response:
            self.consume_record = response['consume_record']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPcreditLoanCreditApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPcreditLoanCreditApplyResponse, self).__init__()
        self._credit_receipt_no = None
        self._redirect_url = None

    @property
    def credit_receipt_no(self):
        return self._credit_receipt_no

    @credit_receipt_no.setter
    def credit_receipt_no(self, value):
        self._credit_receipt_no = value
    @property
    def redirect_url(self):
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, value):
        self._redirect_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayPcreditLoanCreditApplyResponse, self).parse_response_content(response_content)
        if 'credit_receipt_no' in response:
            self.credit_receipt_no = response['credit_receipt_no']
        if 'redirect_url' in response:
            self.redirect_url = response['redirect_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankEcnyTradeRefundResponse(AlipayResponse):

    def __init__(self):
        super(MybankEcnyTradeRefundResponse, self).__init__()
        self._fund_change = None
        self._out_trade_no = None
        self._refund_fee = None
        self._trade_no = None

    @property
    def fund_change(self):
        return self._fund_change

    @fund_change.setter
    def fund_change(self, value):
        self._fund_change = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def refund_fee(self):
        return self._refund_fee

    @refund_fee.setter
    def refund_fee(self, value):
        self._refund_fee = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(MybankEcnyTradeRefundResponse, self).parse_response_content(response_content)
        if 'fund_change' in response:
            self.fund_change = response['fund_change']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'refund_fee' in response:
            self.refund_fee = response['refund_fee']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainDefinInsuranceUnifiedApplyResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinInsuranceUnifiedApplyResponse, self).__init__()
        self._biz_message = None
        self._inst_apply_no = None
        self._inst_policy_no = None
        self._policy_status = None
        self._premium = None
        self._request_no = None

    @property
    def biz_message(self):
        return self._biz_message

    @biz_message.setter
    def biz_message(self, value):
        self._biz_message = value
    @property
    def inst_apply_no(self):
        return self._inst_apply_no

    @inst_apply_no.setter
    def inst_apply_no(self, value):
        self._inst_apply_no = value
    @property
    def inst_policy_no(self):
        return self._inst_policy_no

    @inst_policy_no.setter
    def inst_policy_no(self, value):
        self._inst_policy_no = value
    @property
    def policy_status(self):
        return self._policy_status

    @policy_status.setter
    def policy_status(self, value):
        self._policy_status = value
    @property
    def premium(self):
        return self._premium

    @premium.setter
    def premium(self, value):
        self._premium = value
    @property
    def request_no(self):
        return self._request_no

    @request_no.setter
    def request_no(self, value):
        self._request_no = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinInsuranceUnifiedApplyResponse, self).parse_response_content(response_content)
        if 'biz_message' in response:
            self.biz_message = response['biz_message']
        if 'inst_apply_no' in response:
            self.inst_apply_no = response['inst_apply_no']
        if 'inst_policy_no' in response:
            self.inst_policy_no = response['inst_policy_no']
        if 'policy_status' in response:
            self.policy_status = response['policy_status']
        if 'premium' in response:
            self.premium = response['premium']
        if 'request_no' in response:
            self.request_no = response['request_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppFacepayBillQueryModel(object):

    def __init__(self):
        self._bill_no = None
        self._out_order_no = None
        self._user_id = None
        self._user_identity_code = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_identity_code(self):
        return self._user_identity_code

    @user_identity_code.setter
    def user_identity_code(self, value):
        self._user_identity_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_identity_code:
            if hasattr(self.user_identity_code, 'to_alipay_dict'):
                params['user_identity_code'] = self.user_identity_code.to_alipay_dict()
            else:
                params['user_identity_code'] = self.user_identity_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppFacepayBillQueryModel()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_identity_code' in d:
            o.user_identity_code = d['user_identity_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.FileItem import FileItem
from alipay.aop.api.constant.ParamConstants import *




class ZhimaMerchantCloseloopDataUploadRequest(object):

    def __init__(self, biz_model=None):
        self._biz_model = biz_model
        self._biz_ext_params = None
        self._columns = None
        self._file_charset = None
        self._linked_merchant_id = None
        self._primary_key_columns = None
        self._records = None
        self._scene_code = None
        self._file = None
        self._version = "1.0"
        self._terminal_type = None
        self._terminal_info = None
        self._prod_code = None
        self._notify_url = None
        self._return_url = None
        self._udf_params = None
        self._need_encrypt = False

    @property
    def biz_model(self):
        return self._biz_model

    @biz_model.setter
    def biz_model(self, value):
        self._biz_model = value

    @property
    def biz_ext_params(self):
        return self._biz_ext_params

    @biz_ext_params.setter
    def biz_ext_params(self, value):
        self._biz_ext_params = value
    @property
    def columns(self):
        return self._columns

    @columns.setter
    def columns(self, value):
        self._columns = value
    @property
    def file_charset(self):
        return self._file_charset

    @file_charset.setter
    def file_charset(self, value):
        self._file_charset = value
    @property
    def linked_merchant_id(self):
        return self._linked_merchant_id

    @linked_merchant_id.setter
    def linked_merchant_id(self, value):
        self._linked_merchant_id = value
    @property
    def primary_key_columns(self):
        return self._primary_key_columns

    @primary_key_columns.setter
    def primary_key_columns(self, value):
        self._primary_key_columns = value
    @property
    def records(self):
        return self._records

    @records.setter
    def records(self, value):
        self._records = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value

    @property
    def file(self):
        return self._file

    @file.setter
    def file(self, value):
        if not isinstance(value, FileItem):
            return
        self._file = value

    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value

    @property
    def terminal_type(self):
        return self._terminal_type

    @terminal_type.setter
    def terminal_type(self, value):
        self._terminal_type = value

    @property
    def terminal_info(self):
        return self._terminal_info

    @terminal_info.setter
    def terminal_info(self, value):
        self._terminal_info = value

    @property
    def prod_code(self):
        return self._prod_code

    @prod_code.setter
    def prod_code(self, value):
        self._prod_code = value

    @property
    def notify_url(self):
        return self._notify_url

    @notify_url.setter
    def notify_url(self, value):
        self._notify_url = value

    @property
    def return_url(self):
        return self._return_url

    @return_url.setter
    def return_url(self, value):
        self._return_url = value

    @property
    def udf_params(self):
        return self._udf_params

    @udf_params.setter
    def udf_params(self, value):
        if not isinstance(value, dict):
            return
        self._udf_params = value

    @property
    def need_encrypt(self):
        return self._need_encrypt

    @need_encrypt.setter
    def need_encrypt(self, value):
        self._need_encrypt = value

    def add_other_text_param(self, key, value):
        if not self.udf_params:
            self.udf_params = dict()
        self.udf_params[key] = value

    def get_params(self):
        params = dict()
        params[P_METHOD] = 'zhima.merchant.closeloop.data.upload'
        params[P_VERSION] = self.version
        if self.biz_model:
            params[P_BIZ_CONTENT] = json.dumps(obj=self.biz_model.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
        if self.biz_ext_params:
            if hasattr(self.biz_ext_params, 'to_alipay_dict'):
                params['biz_ext_params'] = json.dumps(obj=self.biz_ext_params.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['biz_ext_params'] = self.biz_ext_params
        if self.columns:
            if hasattr(self.columns, 'to_alipay_dict'):
                params['columns'] = json.dumps(obj=self.columns.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['columns'] = self.columns
        if self.file_charset:
            if hasattr(self.file_charset, 'to_alipay_dict'):
                params['file_charset'] = json.dumps(obj=self.file_charset.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['file_charset'] = self.file_charset
        if self.linked_merchant_id:
            if hasattr(self.linked_merchant_id, 'to_alipay_dict'):
                params['linked_merchant_id'] = json.dumps(obj=self.linked_merchant_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['linked_merchant_id'] = self.linked_merchant_id
        if self.primary_key_columns:
            if hasattr(self.primary_key_columns, 'to_alipay_dict'):
                params['primary_key_columns'] = json.dumps(obj=self.primary_key_columns.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['primary_key_columns'] = self.primary_key_columns
        if self.records:
            if hasattr(self.records, 'to_alipay_dict'):
                params['records'] = json.dumps(obj=self.records.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['records'] = self.records
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = json.dumps(obj=self.scene_code.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
            else:
                params['scene_code'] = self.scene_code
        if self.terminal_type:
            params['terminal_type'] = self.terminal_type
        if self.terminal_info:
            params['terminal_info'] = self.terminal_info
        if self.prod_code:
            params['prod_code'] = self.prod_code
        if self.notify_url:
            params['notify_url'] = self.notify_url
        if self.return_url:
            params['return_url'] = self.return_url
        if self.udf_params:
            params.update(self.udf_params)
        return params

    def get_multipart_params(self):
        multipart_params = dict()
        if self.file:
            multipart_params['file'] = self.file
        return multipart_params



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BusinessRelationShopAddresss import BusinessRelationShopAddresss
from alipay.aop.api.domain.BusinessRelationExtInfo import BusinessRelationExtInfo


class BusinessRelationShopDetailInfo(object):

    def __init__(self):
        self._business_address = None
        self._cert_image = None
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._contact_mobile = None
        self._contact_phone = None
        self._ext_infos = None
        self._out_door_images = None
        self._real_shop_id = None
        self._real_shop_logo = None
        self._real_shop_no = None
        self._shop_category = None
        self._shop_name = None

    @property
    def business_address(self):
        return self._business_address

    @business_address.setter
    def business_address(self, value):
        if isinstance(value, list):
            self._business_address = list()
            for i in value:
                if isinstance(i, BusinessRelationShopAddresss):
                    self._business_address.append(i)
                else:
                    self._business_address.append(BusinessRelationShopAddresss.from_alipay_dict(i))
    @property
    def cert_image(self):
        return self._cert_image

    @cert_image.setter
    def cert_image(self, value):
        self._cert_image = value
    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def contact_phone(self):
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, value):
        self._contact_phone = value
    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        if isinstance(value, BusinessRelationExtInfo):
            self._ext_infos = value
        else:
            self._ext_infos = BusinessRelationExtInfo.from_alipay_dict(value)
    @property
    def out_door_images(self):
        return self._out_door_images

    @out_door_images.setter
    def out_door_images(self, value):
        if isinstance(value, list):
            self._out_door_images = list()
            for i in value:
                self._out_door_images.append(i)
    @property
    def real_shop_id(self):
        return self._real_shop_id

    @real_shop_id.setter
    def real_shop_id(self, value):
        self._real_shop_id = value
    @property
    def real_shop_logo(self):
        return self._real_shop_logo

    @real_shop_logo.setter
    def real_shop_logo(self, value):
        self._real_shop_logo = value
    @property
    def real_shop_no(self):
        return self._real_shop_no

    @real_shop_no.setter
    def real_shop_no(self, value):
        self._real_shop_no = value
    @property
    def shop_category(self):
        return self._shop_category

    @shop_category.setter
    def shop_category(self, value):
        self._shop_category = value
    @property
    def shop_name(self):
        return self._shop_name

    @shop_name.setter
    def shop_name(self, value):
        self._shop_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_address:
            if isinstance(self.business_address, list):
                for i in range(0, len(self.business_address)):
                    element = self.business_address[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.business_address[i] = element.to_alipay_dict()
            if hasattr(self.business_address, 'to_alipay_dict'):
                params['business_address'] = self.business_address.to_alipay_dict()
            else:
                params['business_address'] = self.business_address
        if self.cert_image:
            if hasattr(self.cert_image, 'to_alipay_dict'):
                params['cert_image'] = self.cert_image.to_alipay_dict()
            else:
                params['cert_image'] = self.cert_image
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.contact_phone:
            if hasattr(self.contact_phone, 'to_alipay_dict'):
                params['contact_phone'] = self.contact_phone.to_alipay_dict()
            else:
                params['contact_phone'] = self.contact_phone
        if self.ext_infos:
            if hasattr(self.ext_infos, 'to_alipay_dict'):
                params['ext_infos'] = self.ext_infos.to_alipay_dict()
            else:
                params['ext_infos'] = self.ext_infos
        if self.out_door_images:
            if isinstance(self.out_door_images, list):
                for i in range(0, len(self.out_door_images)):
                    element = self.out_door_images[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.out_door_images[i] = element.to_alipay_dict()
            if hasattr(self.out_door_images, 'to_alipay_dict'):
                params['out_door_images'] = self.out_door_images.to_alipay_dict()
            else:
                params['out_door_images'] = self.out_door_images
        if self.real_shop_id:
            if hasattr(self.real_shop_id, 'to_alipay_dict'):
                params['real_shop_id'] = self.real_shop_id.to_alipay_dict()
            else:
                params['real_shop_id'] = self.real_shop_id
        if self.real_shop_logo:
            if hasattr(self.real_shop_logo, 'to_alipay_dict'):
                params['real_shop_logo'] = self.real_shop_logo.to_alipay_dict()
            else:
                params['real_shop_logo'] = self.real_shop_logo
        if self.real_shop_no:
            if hasattr(self.real_shop_no, 'to_alipay_dict'):
                params['real_shop_no'] = self.real_shop_no.to_alipay_dict()
            else:
                params['real_shop_no'] = self.real_shop_no
        if self.shop_category:
            if hasattr(self.shop_category, 'to_alipay_dict'):
                params['shop_category'] = self.shop_category.to_alipay_dict()
            else:
                params['shop_category'] = self.shop_category
        if self.shop_name:
            if hasattr(self.shop_name, 'to_alipay_dict'):
                params['shop_name'] = self.shop_name.to_alipay_dict()
            else:
                params['shop_name'] = self.shop_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessRelationShopDetailInfo()
        if 'business_address' in d:
            o.business_address = d['business_address']
        if 'cert_image' in d:
            o.cert_image = d['cert_image']
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'contact_phone' in d:
            o.contact_phone = d['contact_phone']
        if 'ext_infos' in d:
            o.ext_infos = d['ext_infos']
        if 'out_door_images' in d:
            o.out_door_images = d['out_door_images']
        if 'real_shop_id' in d:
            o.real_shop_id = d['real_shop_id']
        if 'real_shop_logo' in d:
            o.real_shop_logo = d['real_shop_logo']
        if 'real_shop_no' in d:
            o.real_shop_no = d['real_shop_no']
        if 'shop_category' in d:
            o.shop_category = d['shop_category']
        if 'shop_name' in d:
            o.shop_name = d['shop_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiSelleradmitRealtimeCertifyModel(object):

    def __init__(self):
        self._alipay_id = None
        self._from_app = None
        self._industry = None
        self._main_category = None
        self._platform = None
        self._seller_admit_scene = None
        self._seller_id = None

    @property
    def alipay_id(self):
        return self._alipay_id

    @alipay_id.setter
    def alipay_id(self, value):
        self._alipay_id = value
    @property
    def from_app(self):
        return self._from_app

    @from_app.setter
    def from_app(self, value):
        self._from_app = value
    @property
    def industry(self):
        return self._industry

    @industry.setter
    def industry(self, value):
        self._industry = value
    @property
    def main_category(self):
        return self._main_category

    @main_category.setter
    def main_category(self, value):
        self._main_category = value
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value
    @property
    def seller_admit_scene(self):
        return self._seller_admit_scene

    @seller_admit_scene.setter
    def seller_admit_scene(self, value):
        self._seller_admit_scene = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_id:
            if hasattr(self.alipay_id, 'to_alipay_dict'):
                params['alipay_id'] = self.alipay_id.to_alipay_dict()
            else:
                params['alipay_id'] = self.alipay_id
        if self.from_app:
            if hasattr(self.from_app, 'to_alipay_dict'):
                params['from_app'] = self.from_app.to_alipay_dict()
            else:
                params['from_app'] = self.from_app
        if self.industry:
            if hasattr(self.industry, 'to_alipay_dict'):
                params['industry'] = self.industry.to_alipay_dict()
            else:
                params['industry'] = self.industry
        if self.main_category:
            if hasattr(self.main_category, 'to_alipay_dict'):
                params['main_category'] = self.main_category.to_alipay_dict()
            else:
                params['main_category'] = self.main_category
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        if self.seller_admit_scene:
            if hasattr(self.seller_admit_scene, 'to_alipay_dict'):
                params['seller_admit_scene'] = self.seller_admit_scene.to_alipay_dict()
            else:
                params['seller_admit_scene'] = self.seller_admit_scene
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiSelleradmitRealtimeCertifyModel()
        if 'alipay_id' in d:
            o.alipay_id = d['alipay_id']
        if 'from_app' in d:
            o.from_app = d['from_app']
        if 'industry' in d:
            o.industry = d['industry']
        if 'main_category' in d:
            o.main_category = d['main_category']
        if 'platform' in d:
            o.platform = d['platform']
        if 'seller_admit_scene' in d:
            o.seller_admit_scene = d['seller_admit_scene']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ApplyBizBudgetRequest(object):

    def __init__(self):
        self._amount = None
        self._amount_type = None
        self._biz_budget_apply_code = None
        self._biz_date = None
        self._biz_name = None
        self._biz_type = None
        self._biz_uk_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def amount_type(self):
        return self._amount_type

    @amount_type.setter
    def amount_type(self, value):
        self._amount_type = value
    @property
    def biz_budget_apply_code(self):
        return self._biz_budget_apply_code

    @biz_budget_apply_code.setter
    def biz_budget_apply_code(self, value):
        self._biz_budget_apply_code = value
    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def biz_name(self):
        return self._biz_name

    @biz_name.setter
    def biz_name(self, value):
        self._biz_name = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def biz_uk_id(self):
        return self._biz_uk_id

    @biz_uk_id.setter
    def biz_uk_id(self, value):
        self._biz_uk_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.amount_type:
            if hasattr(self.amount_type, 'to_alipay_dict'):
                params['amount_type'] = self.amount_type.to_alipay_dict()
            else:
                params['amount_type'] = self.amount_type
        if self.biz_budget_apply_code:
            if hasattr(self.biz_budget_apply_code, 'to_alipay_dict'):
                params['biz_budget_apply_code'] = self.biz_budget_apply_code.to_alipay_dict()
            else:
                params['biz_budget_apply_code'] = self.biz_budget_apply_code
        if self.biz_date:
            if hasattr(self.biz_date, 'to_alipay_dict'):
                params['biz_date'] = self.biz_date.to_alipay_dict()
            else:
                params['biz_date'] = self.biz_date
        if self.biz_name:
            if hasattr(self.biz_name, 'to_alipay_dict'):
                params['biz_name'] = self.biz_name.to_alipay_dict()
            else:
                params['biz_name'] = self.biz_name
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.biz_uk_id:
            if hasattr(self.biz_uk_id, 'to_alipay_dict'):
                params['biz_uk_id'] = self.biz_uk_id.to_alipay_dict()
            else:
                params['biz_uk_id'] = self.biz_uk_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApplyBizBudgetRequest()
        if 'amount' in d:
            o.amount = d['amount']
        if 'amount_type' in d:
            o.amount_type = d['amount_type']
        if 'biz_budget_apply_code' in d:
            o.biz_budget_apply_code = d['biz_budget_apply_code']
        if 'biz_date' in d:
            o.biz_date = d['biz_date']
        if 'biz_name' in d:
            o.biz_name = d['biz_name']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'biz_uk_id' in d:
            o.biz_uk_id = d['biz_uk_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOverseasTaxUserinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOverseasTaxUserinfoQueryResponse, self).__init__()
        self._eligible = None
        self._eligible_msg = None
        self._logon_id = None
        self._user_id = None
        self._user_name = None

    @property
    def eligible(self):
        return self._eligible

    @eligible.setter
    def eligible(self, value):
        self._eligible = value
    @property
    def eligible_msg(self):
        return self._eligible_msg

    @eligible_msg.setter
    def eligible_msg(self, value):
        self._eligible_msg = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        self._logon_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayOverseasTaxUserinfoQueryResponse, self).parse_response_content(response_content)
        if 'eligible' in response:
            self.eligible = response['eligible']
        if 'eligible_msg' in response:
            self.eligible_msg = response['eligible_msg']
        if 'logon_id' in response:
            self.logon_id = response['logon_id']
        if 'user_id' in response:
            self.user_id = response['user_id']
        if 'user_name' in response:
            self.user_name = response['user_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundBailAgreementUpgradeModel(object):

    def __init__(self):
        self._agreement_no = None
        self._trusteeship_mode = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def trusteeship_mode(self):
        return self._trusteeship_mode

    @trusteeship_mode.setter
    def trusteeship_mode(self, value):
        self._trusteeship_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.trusteeship_mode:
            if hasattr(self.trusteeship_mode, 'to_alipay_dict'):
                params['trusteeship_mode'] = self.trusteeship_mode.to_alipay_dict()
            else:
                params['trusteeship_mode'] = self.trusteeship_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundBailAgreementUpgradeModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'trusteeship_mode' in d:
            o.trusteeship_mode = d['trusteeship_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AppTokenExchangeSubElement import AppTokenExchangeSubElement


class AlipayOpenAuthTokenAppResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAuthTokenAppResponse, self).__init__()
        self._app_auth_token = None
        self._app_refresh_token = None
        self._auth_app_id = None
        self._expires_in = None
        self._re_expires_in = None
        self._tokens = None
        self._user_id = None

    @property
    def app_auth_token(self):
        return self._app_auth_token

    @app_auth_token.setter
    def app_auth_token(self, value):
        self._app_auth_token = value
    @property
    def app_refresh_token(self):
        return self._app_refresh_token

    @app_refresh_token.setter
    def app_refresh_token(self, value):
        self._app_refresh_token = value
    @property
    def auth_app_id(self):
        return self._auth_app_id

    @auth_app_id.setter
    def auth_app_id(self, value):
        self._auth_app_id = value
    @property
    def expires_in(self):
        return self._expires_in

    @expires_in.setter
    def expires_in(self, value):
        self._expires_in = value
    @property
    def re_expires_in(self):
        return self._re_expires_in

    @re_expires_in.setter
    def re_expires_in(self, value):
        self._re_expires_in = value
    @property
    def tokens(self):
        return self._tokens

    @tokens.setter
    def tokens(self, value):
        if isinstance(value, list):
            self._tokens = list()
            for i in value:
                if isinstance(i, AppTokenExchangeSubElement):
                    self._tokens.append(i)
                else:
                    self._tokens.append(AppTokenExchangeSubElement.from_alipay_dict(i))
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAuthTokenAppResponse, self).parse_response_content(response_content)
        if 'app_auth_token' in response:
            self.app_auth_token = response['app_auth_token']
        if 'app_refresh_token' in response:
            self.app_refresh_token = response['app_refresh_token']
        if 'auth_app_id' in response:
            self.auth_app_id = response['auth_app_id']
        if 'expires_in' in response:
            self.expires_in = response['expires_in']
        if 're_expires_in' in response:
            self.re_expires_in = response['re_expires_in']
        if 'tokens' in response:
            self.tokens = response['tokens']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCharityAgreementApplyModel(object):

    def __init__(self):
        self._biz_id = None
        self._product_code = None
        self._withhold_pid = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def withhold_pid(self):
        return self._withhold_pid

    @withhold_pid.setter
    def withhold_pid(self, value):
        self._withhold_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.withhold_pid:
            if hasattr(self.withhold_pid, 'to_alipay_dict'):
                params['withhold_pid'] = self.withhold_pid.to_alipay_dict()
            else:
                params['withhold_pid'] = self.withhold_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCharityAgreementApplyModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'withhold_pid' in d:
            o.withhold_pid = d['withhold_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Command import Command


class AlipayInsSceneCommandReceiveModel(object):

    def __init__(self):
        self._command = None

    @property
    def command(self):
        return self._command

    @command.setter
    def command(self, value):
        if isinstance(value, Command):
            self._command = value
        else:
            self._command = Command.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.command:
            if hasattr(self.command, 'to_alipay_dict'):
                params['command'] = self.command.to_alipay_dict()
            else:
                params['command'] = self.command
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneCommandReceiveModel()
        if 'command' in d:
            o.command = d['command']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SocialInfoView import SocialInfoView


class AlipayUserSocialinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserSocialinfoQueryResponse, self).__init__()
        self._social_info_views = None

    @property
    def social_info_views(self):
        return self._social_info_views

    @social_info_views.setter
    def social_info_views(self, value):
        if isinstance(value, list):
            self._social_info_views = list()
            for i in value:
                if isinstance(i, SocialInfoView):
                    self._social_info_views.append(i)
                else:
                    self._social_info_views.append(SocialInfoView.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayUserSocialinfoQueryResponse, self).parse_response_content(response_content)
        if 'social_info_views' in response:
            self.social_info_views = response['social_info_views']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMerchantOperatorModifyModel(object):

    def __init__(self):
        self._auth_code = None
        self._department_id = None
        self._discount_limit_unit = None
        self._discount_limit_value = None
        self._free_limit_unit = None
        self._free_limit_value = None
        self._gender = None
        self._job_type = None
        self._mobile = None
        self._operator_id = None
        self._operator_name = None
        self._role_id = None

    @property
    def auth_code(self):
        return self._auth_code

    @auth_code.setter
    def auth_code(self, value):
        self._auth_code = value
    @property
    def department_id(self):
        return self._department_id

    @department_id.setter
    def department_id(self, value):
        self._department_id = value
    @property
    def discount_limit_unit(self):
        return self._discount_limit_unit

    @discount_limit_unit.setter
    def discount_limit_unit(self, value):
        self._discount_limit_unit = value
    @property
    def discount_limit_value(self):
        return self._discount_limit_value

    @discount_limit_value.setter
    def discount_limit_value(self, value):
        self._discount_limit_value = value
    @property
    def free_limit_unit(self):
        return self._free_limit_unit

    @free_limit_unit.setter
    def free_limit_unit(self, value):
        self._free_limit_unit = value
    @property
    def free_limit_value(self):
        return self._free_limit_value

    @free_limit_value.setter
    def free_limit_value(self, value):
        self._free_limit_value = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def job_type(self):
        return self._job_type

    @job_type.setter
    def job_type(self, value):
        self._job_type = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def role_id(self):
        return self._role_id

    @role_id.setter
    def role_id(self, value):
        self._role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_code:
            if hasattr(self.auth_code, 'to_alipay_dict'):
                params['auth_code'] = self.auth_code.to_alipay_dict()
            else:
                params['auth_code'] = self.auth_code
        if self.department_id:
            if hasattr(self.department_id, 'to_alipay_dict'):
                params['department_id'] = self.department_id.to_alipay_dict()
            else:
                params['department_id'] = self.department_id
        if self.discount_limit_unit:
            if hasattr(self.discount_limit_unit, 'to_alipay_dict'):
                params['discount_limit_unit'] = self.discount_limit_unit.to_alipay_dict()
            else:
                params['discount_limit_unit'] = self.discount_limit_unit
        if self.discount_limit_value:
            if hasattr(self.discount_limit_value, 'to_alipay_dict'):
                params['discount_limit_value'] = self.discount_limit_value.to_alipay_dict()
            else:
                params['discount_limit_value'] = self.discount_limit_value
        if self.free_limit_unit:
            if hasattr(self.free_limit_unit, 'to_alipay_dict'):
                params['free_limit_unit'] = self.free_limit_unit.to_alipay_dict()
            else:
                params['free_limit_unit'] = self.free_limit_unit
        if self.free_limit_value:
            if hasattr(self.free_limit_value, 'to_alipay_dict'):
                params['free_limit_value'] = self.free_limit_value.to_alipay_dict()
            else:
                params['free_limit_value'] = self.free_limit_value
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.job_type:
            if hasattr(self.job_type, 'to_alipay_dict'):
                params['job_type'] = self.job_type.to_alipay_dict()
            else:
                params['job_type'] = self.job_type
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.role_id:
            if hasattr(self.role_id, 'to_alipay_dict'):
                params['role_id'] = self.role_id.to_alipay_dict()
            else:
                params['role_id'] = self.role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMerchantOperatorModifyModel()
        if 'auth_code' in d:
            o.auth_code = d['auth_code']
        if 'department_id' in d:
            o.department_id = d['department_id']
        if 'discount_limit_unit' in d:
            o.discount_limit_unit = d['discount_limit_unit']
        if 'discount_limit_value' in d:
            o.discount_limit_value = d['discount_limit_value']
        if 'free_limit_unit' in d:
            o.free_limit_unit = d['free_limit_unit']
        if 'free_limit_value' in d:
            o.free_limit_value = d['free_limit_value']
        if 'gender' in d:
            o.gender = d['gender']
        if 'job_type' in d:
            o.job_type = d['job_type']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'role_id' in d:
            o.role_id = d['role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.HouseOwner import HouseOwner


class House(object):

    def __init__(self):
        self._area_code = None
        self._built_year = None
        self._house_owners = None
        self._house_unit_codes = None
        self._its_floor = None
        self._land_cert_no = None
        self._location = None
        self._mortgaged = None
        self._owner_ship_status = None
        self._structure_area = None
        self._structure_area_unit = None
        self._total_floor = None

    @property
    def area_code(self):
        return self._area_code

    @area_code.setter
    def area_code(self, value):
        self._area_code = value
    @property
    def built_year(self):
        return self._built_year

    @built_year.setter
    def built_year(self, value):
        self._built_year = value
    @property
    def house_owners(self):
        return self._house_owners

    @house_owners.setter
    def house_owners(self, value):
        if isinstance(value, list):
            self._house_owners = list()
            for i in value:
                if isinstance(i, HouseOwner):
                    self._house_owners.append(i)
                else:
                    self._house_owners.append(HouseOwner.from_alipay_dict(i))
    @property
    def house_unit_codes(self):
        return self._house_unit_codes

    @house_unit_codes.setter
    def house_unit_codes(self, value):
        if isinstance(value, list):
            self._house_unit_codes = list()
            for i in value:
                self._house_unit_codes.append(i)
    @property
    def its_floor(self):
        return self._its_floor

    @its_floor.setter
    def its_floor(self, value):
        self._its_floor = value
    @property
    def land_cert_no(self):
        return self._land_cert_no

    @land_cert_no.setter
    def land_cert_no(self, value):
        self._land_cert_no = value
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        self._location = value
    @property
    def mortgaged(self):
        return self._mortgaged

    @mortgaged.setter
    def mortgaged(self, value):
        self._mortgaged = value
    @property
    def owner_ship_status(self):
        return self._owner_ship_status

    @owner_ship_status.setter
    def owner_ship_status(self, value):
        self._owner_ship_status = value
    @property
    def structure_area(self):
        return self._structure_area

    @structure_area.setter
    def structure_area(self, value):
        self._structure_area = value
    @property
    def structure_area_unit(self):
        return self._structure_area_unit

    @structure_area_unit.setter
    def structure_area_unit(self, value):
        self._structure_area_unit = value
    @property
    def total_floor(self):
        return self._total_floor

    @total_floor.setter
    def total_floor(self, value):
        self._total_floor = value


    def to_alipay_dict(self):
        params = dict()
        if self.area_code:
            if hasattr(self.area_code, 'to_alipay_dict'):
                params['area_code'] = self.area_code.to_alipay_dict()
            else:
                params['area_code'] = self.area_code
        if self.built_year:
            if hasattr(self.built_year, 'to_alipay_dict'):
                params['built_year'] = self.built_year.to_alipay_dict()
            else:
                params['built_year'] = self.built_year
        if self.house_owners:
            if isinstance(self.house_owners, list):
                for i in range(0, len(self.house_owners)):
                    element = self.house_owners[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.house_owners[i] = element.to_alipay_dict()
            if hasattr(self.house_owners, 'to_alipay_dict'):
                params['house_owners'] = self.house_owners.to_alipay_dict()
            else:
                params['house_owners'] = self.house_owners
        if self.house_unit_codes:
            if isinstance(self.house_unit_codes, list):
                for i in range(0, len(self.house_unit_codes)):
                    element = self.house_unit_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.house_unit_codes[i] = element.to_alipay_dict()
            if hasattr(self.house_unit_codes, 'to_alipay_dict'):
                params['house_unit_codes'] = self.house_unit_codes.to_alipay_dict()
            else:
                params['house_unit_codes'] = self.house_unit_codes
        if self.its_floor:
            if hasattr(self.its_floor, 'to_alipay_dict'):
                params['its_floor'] = self.its_floor.to_alipay_dict()
            else:
                params['its_floor'] = self.its_floor
        if self.land_cert_no:
            if hasattr(self.land_cert_no, 'to_alipay_dict'):
                params['land_cert_no'] = self.land_cert_no.to_alipay_dict()
            else:
                params['land_cert_no'] = self.land_cert_no
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.mortgaged:
            if hasattr(self.mortgaged, 'to_alipay_dict'):
                params['mortgaged'] = self.mortgaged.to_alipay_dict()
            else:
                params['mortgaged'] = self.mortgaged
        if self.owner_ship_status:
            if hasattr(self.owner_ship_status, 'to_alipay_dict'):
                params['owner_ship_status'] = self.owner_ship_status.to_alipay_dict()
            else:
                params['owner_ship_status'] = self.owner_ship_status
        if self.structure_area:
            if hasattr(self.structure_area, 'to_alipay_dict'):
                params['structure_area'] = self.structure_area.to_alipay_dict()
            else:
                params['structure_area'] = self.structure_area
        if self.structure_area_unit:
            if hasattr(self.structure_area_unit, 'to_alipay_dict'):
                params['structure_area_unit'] = self.structure_area_unit.to_alipay_dict()
            else:
                params['structure_area_unit'] = self.structure_area_unit
        if self.total_floor:
            if hasattr(self.total_floor, 'to_alipay_dict'):
                params['total_floor'] = self.total_floor.to_alipay_dict()
            else:
                params['total_floor'] = self.total_floor
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = House()
        if 'area_code' in d:
            o.area_code = d['area_code']
        if 'built_year' in d:
            o.built_year = d['built_year']
        if 'house_owners' in d:
            o.house_owners = d['house_owners']
        if 'house_unit_codes' in d:
            o.house_unit_codes = d['house_unit_codes']
        if 'its_floor' in d:
            o.its_floor = d['its_floor']
        if 'land_cert_no' in d:
            o.land_cert_no = d['land_cert_no']
        if 'location' in d:
            o.location = d['location']
        if 'mortgaged' in d:
            o.mortgaged = d['mortgaged']
        if 'owner_ship_status' in d:
            o.owner_ship_status = d['owner_ship_status']
        if 'structure_area' in d:
            o.structure_area = d['structure_area']
        if 'structure_area_unit' in d:
            o.structure_area_unit = d['structure_area_unit']
        if 'total_floor' in d:
            o.total_floor = d['total_floor']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAgreementUserverifyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAgreementUserverifyQueryResponse, self).__init__()
        self._user_match = None

    @property
    def user_match(self):
        return self._user_match

    @user_match.setter
    def user_match(self, value):
        self._user_match = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAgreementUserverifyQueryResponse, self).parse_response_content(response_content)
        if 'user_match' in response:
            self.user_match = response['user_match']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserAntpaasTokenThirdTrustLoginModel(object):

    def __init__(self):
        self._login_target = None

    @property
    def login_target(self):
        return self._login_target

    @login_target.setter
    def login_target(self, value):
        self._login_target = value


    def to_alipay_dict(self):
        params = dict()
        if self.login_target:
            if hasattr(self.login_target, 'to_alipay_dict'):
                params['login_target'] = self.login_target.to_alipay_dict()
            else:
                params['login_target'] = self.login_target
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAntpaasTokenThirdTrustLoginModel()
        if 'login_target' in d:
            o.login_target = d['login_target']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CraftsmanWorkCreateOpenModel(object):

    def __init__(self):
        self._duration = None
        self._media_id = None
        self._media_type = None
        self._out_work_id = None
        self._title = None

    @property
    def duration(self):
        return self._duration

    @duration.setter
    def duration(self, value):
        self._duration = value
    @property
    def media_id(self):
        return self._media_id

    @media_id.setter
    def media_id(self, value):
        self._media_id = value
    @property
    def media_type(self):
        return self._media_type

    @media_type.setter
    def media_type(self, value):
        self._media_type = value
    @property
    def out_work_id(self):
        return self._out_work_id

    @out_work_id.setter
    def out_work_id(self, value):
        self._out_work_id = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.duration:
            if hasattr(self.duration, 'to_alipay_dict'):
                params['duration'] = self.duration.to_alipay_dict()
            else:
                params['duration'] = self.duration
        if self.media_id:
            if hasattr(self.media_id, 'to_alipay_dict'):
                params['media_id'] = self.media_id.to_alipay_dict()
            else:
                params['media_id'] = self.media_id
        if self.media_type:
            if hasattr(self.media_type, 'to_alipay_dict'):
                params['media_type'] = self.media_type.to_alipay_dict()
            else:
                params['media_type'] = self.media_type
        if self.out_work_id:
            if hasattr(self.out_work_id, 'to_alipay_dict'):
                params['out_work_id'] = self.out_work_id.to_alipay_dict()
            else:
                params['out_work_id'] = self.out_work_id
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CraftsmanWorkCreateOpenModel()
        if 'duration' in d:
            o.duration = d['duration']
        if 'media_id' in d:
            o.media_id = d['media_id']
        if 'media_type' in d:
            o.media_type = d['media_type']
        if 'out_work_id' in d:
            o.out_work_id = d['out_work_id']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PluginUseRelationInfo import PluginUseRelationInfo


class AlipayOpenMiniInnerappPluginrelationQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInnerappPluginrelationQueryResponse, self).__init__()
        self._page = None
        self._page_size = None
        self._plugin_relation_info_list = None
        self._total_count = None

    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def plugin_relation_info_list(self):
        return self._plugin_relation_info_list

    @plugin_relation_info_list.setter
    def plugin_relation_info_list(self, value):
        if isinstance(value, list):
            self._plugin_relation_info_list = list()
            for i in value:
                if isinstance(i, PluginUseRelationInfo):
                    self._plugin_relation_info_list.append(i)
                else:
                    self._plugin_relation_info_list.append(PluginUseRelationInfo.from_alipay_dict(i))
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInnerappPluginrelationQueryResponse, self).parse_response_content(response_content)
        if 'page' in response:
            self.page = response['page']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'plugin_relation_info_list' in response:
            self.plugin_relation_info_list = response['plugin_relation_info_list']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.IsvShopDishModel import IsvShopDishModel


class AlipayOfflineProviderDishQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOfflineProviderDishQueryResponse, self).__init__()
        self._items = None
        self._list = None
        self._page = None
        self._page_size = None
        self._pages = None

    @property
    def items(self):
        return self._items

    @items.setter
    def items(self, value):
        self._items = value
    @property
    def list(self):
        return self._list

    @list.setter
    def list(self, value):
        if isinstance(value, list):
            self._list = list()
            for i in value:
                if isinstance(i, IsvShopDishModel):
                    self._list.append(i)
                else:
                    self._list.append(IsvShopDishModel.from_alipay_dict(i))
    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def pages(self):
        return self._pages

    @pages.setter
    def pages(self, value):
        self._pages = value

    def parse_response_content(self, response_content):
        response = super(AlipayOfflineProviderDishQueryResponse, self).parse_response_content(response_content)
        if 'items' in response:
            self.items = response['items']
        if 'list' in response:
            self.list = response['list']
        if 'page' in response:
            self.page = response['page']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'pages' in response:
            self.pages = response['pages']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class PayContractItemApplyDTO(object):

    def __init__(self):
        self._invoice_received_amount = None
        self._issued_amount = None
        self._item_no = None
        self._item_type = None
        self._need_invoice = None
        self._paid_amount = None
        self._pay_ref_type = None
        self._pay_term = None
        self._pay_term_type = None
        self._payable_amount = None
        self._payment_amount = None
        self._payment_type = None
        self._phase = None
        self._status = None
        self._terms = None

    @property
    def invoice_received_amount(self):
        return self._invoice_received_amount

    @invoice_received_amount.setter
    def invoice_received_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_received_amount = value
        else:
            self._invoice_received_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def issued_amount(self):
        return self._issued_amount

    @issued_amount.setter
    def issued_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._issued_amount = value
        else:
            self._issued_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def item_no(self):
        return self._item_no

    @item_no.setter
    def item_no(self, value):
        self._item_no = value
    @property
    def item_type(self):
        return self._item_type

    @item_type.setter
    def item_type(self, value):
        self._item_type = value
    @property
    def need_invoice(self):
        return self._need_invoice

    @need_invoice.setter
    def need_invoice(self, value):
        self._need_invoice = value
    @property
    def paid_amount(self):
        return self._paid_amount

    @paid_amount.setter
    def paid_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._paid_amount = value
        else:
            self._paid_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def pay_ref_type(self):
        return self._pay_ref_type

    @pay_ref_type.setter
    def pay_ref_type(self, value):
        self._pay_ref_type = value
    @property
    def pay_term(self):
        return self._pay_term

    @pay_term.setter
    def pay_term(self, value):
        self._pay_term = value
    @property
    def pay_term_type(self):
        return self._pay_term_type

    @pay_term_type.setter
    def pay_term_type(self, value):
        self._pay_term_type = value
    @property
    def payable_amount(self):
        return self._payable_amount

    @payable_amount.setter
    def payable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._payable_amount = value
        else:
            self._payable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def payment_amount(self):
        return self._payment_amount

    @payment_amount.setter
    def payment_amount(self, value):
        self._payment_amount = value
    @property
    def payment_type(self):
        return self._payment_type

    @payment_type.setter
    def payment_type(self, value):
        self._payment_type = value
    @property
    def phase(self):
        return self._phase

    @phase.setter
    def phase(self, value):
        self._phase = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def terms(self):
        return self._terms

    @terms.setter
    def terms(self, value):
        self._terms = value


    def to_alipay_dict(self):
        params = dict()
        if self.invoice_received_amount:
            if hasattr(self.invoice_received_amount, 'to_alipay_dict'):
                params['invoice_received_amount'] = self.invoice_received_amount.to_alipay_dict()
            else:
                params['invoice_received_amount'] = self.invoice_received_amount
        if self.issued_amount:
            if hasattr(self.issued_amount, 'to_alipay_dict'):
                params['issued_amount'] = self.issued_amount.to_alipay_dict()
            else:
                params['issued_amount'] = self.issued_amount
        if self.item_no:
            if hasattr(self.item_no, 'to_alipay_dict'):
                params['item_no'] = self.item_no.to_alipay_dict()
            else:
                params['item_no'] = self.item_no
        if self.item_type:
            if hasattr(self.item_type, 'to_alipay_dict'):
                params['item_type'] = self.item_type.to_alipay_dict()
            else:
                params['item_type'] = self.item_type
        if self.need_invoice:
            if hasattr(self.need_invoice, 'to_alipay_dict'):
                params['need_invoice'] = self.need_invoice.to_alipay_dict()
            else:
                params['need_invoice'] = self.need_invoice
        if self.paid_amount:
            if hasattr(self.paid_amount, 'to_alipay_dict'):
                params['paid_amount'] = self.paid_amount.to_alipay_dict()
            else:
                params['paid_amount'] = self.paid_amount
        if self.pay_ref_type:
            if hasattr(self.pay_ref_type, 'to_alipay_dict'):
                params['pay_ref_type'] = self.pay_ref_type.to_alipay_dict()
            else:
                params['pay_ref_type'] = self.pay_ref_type
        if self.pay_term:
            if hasattr(self.pay_term, 'to_alipay_dict'):
                params['pay_term'] = self.pay_term.to_alipay_dict()
            else:
                params['pay_term'] = self.pay_term
        if self.pay_term_type:
            if hasattr(self.pay_term_type, 'to_alipay_dict'):
                params['pay_term_type'] = self.pay_term_type.to_alipay_dict()
            else:
                params['pay_term_type'] = self.pay_term_type
        if self.payable_amount:
            if hasattr(self.payable_amount, 'to_alipay_dict'):
                params['payable_amount'] = self.payable_amount.to_alipay_dict()
            else:
                params['payable_amount'] = self.payable_amount
        if self.payment_amount:
            if hasattr(self.payment_amount, 'to_alipay_dict'):
                params['payment_amount'] = self.payment_amount.to_alipay_dict()
            else:
                params['payment_amount'] = self.payment_amount
        if self.payment_type:
            if hasattr(self.payment_type, 'to_alipay_dict'):
                params['payment_type'] = self.payment_type.to_alipay_dict()
            else:
                params['payment_type'] = self.payment_type
        if self.phase:
            if hasattr(self.phase, 'to_alipay_dict'):
                params['phase'] = self.phase.to_alipay_dict()
            else:
                params['phase'] = self.phase
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.terms:
            if hasattr(self.terms, 'to_alipay_dict'):
                params['terms'] = self.terms.to_alipay_dict()
            else:
                params['terms'] = self.terms
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PayContractItemApplyDTO()
        if 'invoice_received_amount' in d:
            o.invoice_received_amount = d['invoice_received_amount']
        if 'issued_amount' in d:
            o.issued_amount = d['issued_amount']
        if 'item_no' in d:
            o.item_no = d['item_no']
        if 'item_type' in d:
            o.item_type = d['item_type']
        if 'need_invoice' in d:
            o.need_invoice = d['need_invoice']
        if 'paid_amount' in d:
            o.paid_amount = d['paid_amount']
        if 'pay_ref_type' in d:
            o.pay_ref_type = d['pay_ref_type']
        if 'pay_term' in d:
            o.pay_term = d['pay_term']
        if 'pay_term_type' in d:
            o.pay_term_type = d['pay_term_type']
        if 'payable_amount' in d:
            o.payable_amount = d['payable_amount']
        if 'payment_amount' in d:
            o.payment_amount = d['payment_amount']
        if 'payment_type' in d:
            o.payment_type = d['payment_type']
        if 'phase' in d:
            o.phase = d['phase']
        if 'status' in d:
            o.status = d['status']
        if 'terms' in d:
            o.terms = d['terms']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MiniAppVersionBaseInfo import MiniAppVersionBaseInfo


class AlipayOpenMiniInnerversionQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInnerversionQueryResponse, self).__init__()
        self._total_count = None
        self._version_list = None

    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value
    @property
    def version_list(self):
        return self._version_list

    @version_list.setter
    def version_list(self, value):
        if isinstance(value, list):
            self._version_list = list()
            for i in value:
                if isinstance(i, MiniAppVersionBaseInfo):
                    self._version_list.append(i)
                else:
                    self._version_list.append(MiniAppVersionBaseInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInnerversionQueryResponse, self).parse_response_content(response_content)
        if 'total_count' in response:
            self.total_count = response['total_count']
        if 'version_list' in response:
            self.version_list = response['version_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayAssetPointVoucherprodBenefittemplateModifyModel(object):

    def __init__(self):
        self._asset_id = None
        self._asset_type = None
        self._biz_dt = None
        self._biz_no = None
        self._publish_end_time = None
        self._user_id = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def asset_type(self):
        return self._asset_type

    @asset_type.setter
    def asset_type(self, value):
        self._asset_type = value
    @property
    def biz_dt(self):
        return self._biz_dt

    @biz_dt.setter
    def biz_dt(self, value):
        self._biz_dt = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def publish_end_time(self):
        return self._publish_end_time

    @publish_end_time.setter
    def publish_end_time(self, value):
        self._publish_end_time = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.asset_type:
            if hasattr(self.asset_type, 'to_alipay_dict'):
                params['asset_type'] = self.asset_type.to_alipay_dict()
            else:
                params['asset_type'] = self.asset_type
        if self.biz_dt:
            if hasattr(self.biz_dt, 'to_alipay_dict'):
                params['biz_dt'] = self.biz_dt.to_alipay_dict()
            else:
                params['biz_dt'] = self.biz_dt
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.publish_end_time:
            if hasattr(self.publish_end_time, 'to_alipay_dict'):
                params['publish_end_time'] = self.publish_end_time.to_alipay_dict()
            else:
                params['publish_end_time'] = self.publish_end_time
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAssetPointVoucherprodBenefittemplateModifyModel()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'asset_type' in d:
            o.asset_type = d['asset_type']
        if 'biz_dt' in d:
            o.biz_dt = d['biz_dt']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'publish_end_time' in d:
            o.publish_end_time = d['publish_end_time']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


